.. label: Downloads
==================================
Downloads
==================================

Latest release
---------------

The latest stable version of :py:mod:`pyCTQW.MPI` is available to download from `GitHub <https://github.com/josh146/pyctqw/releases/latest/>`_; older releases are also available for download and can be found `here <https://github.com/josh146/pyctqw/tags>`_.

Alternatively, if `pip` is installed, :mod:`pyCTQW` can be installed using `pip`:

.. code-block:: bash
	
	$ pip install pyCTQW

Please see the installation page for more information on installing :mod:`pyCTQW`.


Development version
--------------------

If you would like to try out the development version, ths can be downloaded as an archive (`pyctqw-master.tar.gz <https://github.com/josh146/pyctqw/archive/master.tar.gz>`_) or alternatively, checked out via Git:

.. code-block:: bash

	$ git clone https://github.com/josh146/pyctqw.git

or Subversion:

.. code-block:: bash

	$ svn co https://github.com/josh146/pyctqw

or installed using `pip`:

.. code-block:: bash
	
	$ pip install --allow-unverified pyCTQW pyCTQW==dev		

.. caution::
	The development version may be unstable, and can possibly break
	various functionality from time to time.
